==> freefem++_3.47+dfsg1.orig.tar.gz: freefem++-3.47/web/news.php <==
<html>
<head>
<link rel="stylesheet" href="ffstyle.css" type="text/css">
<meta http-equiv="Content-type" content="text/html; charset=utf-8">
   <meta name="Description" content="FreeFem++ is a language that allows 
the resolution of partial      differential equation using the finite 
element method">
   <meta name="Keywords" content="language, c++, Multi-platform, free      
software, Navier-Stokes, elasticity, convection-diffusion, heat      
equation, linear elliptic PDE's",MPI,"Scientific computing">

   <title>Freefem++ News (May  2014)</title>
   <link href="mailto:frederic.hecht@upmc.fr" rev="Author">

</head>

<?php
include 'phpfiles.php'
?>



<body bgcolor="#FFFFFF" text="#000000" link="#333333" vlink="#330066" alink="#330066">
<div class="thetitle"> FreeFem++ v <? echo $fver ?>  <font size=-1> (<? echo $fdate?>) </font> </div> 
<div class="content">
  <div class="thema">News</div>
<div class="themaBlog">
  <ul>
    
    <li> <b>23/9/2005</b> FreeFem++ and OpenFEM presentation day at IHP
(Paris)&nbsp;: <a
href="http://www.cmap.polytechnique.fr/~allaire/gamni/fem.html">details</a>,
<a href="Journee-Gamni-2005">slides and examples</a> </li>
    
    <li><b>1/10/2005</b> Read or participate in general discussions about
FreeFem++ with the <a
href="http://www.ann.jussieu.fr/mailman/listinfo/freefempp">FreeFem++
mailing list</a>
   </li>
   
    <li><b>16/10/2008</b> Ateliers de Simualtion Num&eacute;rique, (Setif,Alg&eacute;rie)
 &nbsp;: <a
href="http://www.cmap.polytechnique.fr/spip.php?article239"> details</a>, par 
<a href="http://www.cmap.polytechnique.fr/spip.php?article105"> Olivier Pantz </a>
   </li>
   
    <li><b>14-15/09/2009</b></b> 
<font color=black>  The first tutorial and Workshop on FreeFem++  ,   held September 14th and 15th, 2009, in Paris at IHP,  amphi Hermite ,11 Rue Pierre et Marie Curie.</font>
 <A HREF="http://www.ann.jussieu.fr/~hecht/ftp/ff++days/2009"> All Presentation, examples, and data are here  </A>    </li>
   
   
    <li> <b>1-2/09/2010</b> 
<font >  
The second tutorial and Workshop on FreeFem++  , 
 held September 1st and 2nd, 2010, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</font>
<A HREF="http://www.freefem.org/ff2a3/ff++days-2010/"> All Presentation, examples, and data are here </A>
  </li>
    
    <li><b>5-7/12/2011</b><font color=000000> <bf> 
The THIRD tutorial and Workshop on FreeFem++  , 
 held december 5th,6th and 7th, 2010, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf> 
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2011/Schedule.htm">All Presentation, examples, and data are here  here  </A>
 </li>
    
      <li><b>6-7/12/2012</b><font color=000000> <bf>  <font color=black> 
The FOURTH  tutorial and Workshop on FreeFem++ , 
 held december 7th and 7th, 2012, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf> 
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2012/main.htm"> Main </A>, 
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2012/Schedule.html"> All Presentation, examples </A> and
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2012/.">  directory this all data  </A>.
 </font></li>
      <li><b>10-13/12/2013</b><font > <bf>  <font > 
 <A HREF="http://www.ljll.math.upmc.fr/FreeFem++"> 
The Fifth   tutorial and Workshop on FreeFem++ </A>, 
 held december 10th,11th and 12th, 2013, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf> 
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2013/main.htm"> Main </A>, 
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2013/Schedule.html"> All Presentation, examples </A> and
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2013/.">  directory this all data  </A>.
 </font></li>

       <li><b>27-28/05/2014</b><font > <bf>  <font > 
 <A HREF="http://www.tims.ntu.edu.tw/workshop/Default/index.php?WID=177"> 
CASTS-LJLL workshop </A>  on Applied Mathematics and Mathematical Sciences </bf>  A programming language for the FEM : FreeFem++ 

<A HREF="http://homepage.ntu.edu.tw/~twhsheu/twsiamff++/activities.html#activities"> Activity </A>, 
<A HREF="http://homepage.ntu.edu.tw/~twhsheu/twsiamff++/courses.html"> Courses </A>.
</font> </font></li>
   
     <li><font > <bf>  <font color=black> 
       The Sixth   tutorial and Workshop on FreeFem++ , 
 held december 9th,10th and 11th, 2014, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf>  
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2014/Schedule.html"> Schedule, All Presentation, examples </A> and
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2014/.">  directory this all data  </A>.
 </font></li> 
 
  <li> <font color=black>  <b>16-20/03/2015</b> <bf>  </font > 

<A HREF="http://www.maths.ox.ac.uk">  Mini Cours FreeFem++, Maths departement, Universty of  Oxford, England  <A/> 16-20 March . 2015   
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++/2015-oxford"> The directory with all data  </A> 
 </li>
 
          <li><font > <bf>  <font color=black> <font color=red> 
       The 7th   tutorial and Workshop on FreeFem++ </font>
 <A HREF="http://www.ljll.math.upmc.fr/FreeFem++">  (inscription here)</A>, 
 held december 15th and 16th, 2015, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf>  
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2015/Schedule.html"> Schedule, All Presentation, examples </A> and
<A HREF="http://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2015/.">  directory this all data  </A>.
 </font></li> 

  </ul>
  
</div> 


<div class="thema"> HPC and FreeFem++  </div>
<ul>
<li> Solver a problem with  one  billion of unknows  in  2 minutes! The computation will done in 2 minutes on the  Curie Thin Node@CEA machine (6144 coeurs de 4Go de mémoire chacun),  Thank to P. Jolivet, and F. Nataf. </li>
<li>  In construction </li>


</ul>

 
<address></address>
<!-- hhmts start --> Last modified: 4 Nov 2015 <!-- hhmts end -->
</body> </html>
</body>
</html>

==> freefem++_3.61.1+dfsg1.orig.tar.gz: freefem++-3.61-1/web/news.php <==
<html>
<head>
<link rel="stylesheet" href="ffstyle.css" type="text/css">
<meta http-equiv="Content-type" content="text/html; charset=utf-8">
   <meta name="Description" content="FreeFem++ is a language that allows 
the resolution of partial      differential equation using the finite 
element method">
   <meta name="Keywords" content="language, c++, Multi-platform, free      
software, Navier-Stokes, elasticity, convection-diffusion, heat      
equation, linear elliptic PDE's",MPI,"Scientific computing">

   <title>Freefem++ News (May  2014)</title>
   <link href="mailto:frederic.hecht@upmc.fr" rev="Author">

</head>

<?php
include 'phpfiles.php'
?>



<body bgcolor="#FFFFFF" text="#000000" link="#333333" vlink="#330066" alink="#330066">
<div class="thetitle"> FreeFem++ v <? echo $fver ?>  <font size=-1> (<? echo $fdate?>) </font> </div> 
<div class="content">
  <div class="thema">News</div>
<div class="themaBlog">
  <ul>
    
    <li> <b>23/9/2005</b> FreeFem++ and OpenFEM presentation day at IHP
(Paris)&nbsp;: <a
href="http://www.cmap.polytechnique.fr/~allaire/gamni/fem.html">details</a>,
<a href="Journee-Gamni-2005">slides and examples</a> </li>
    
    <li><b>1/10/2005</b> Read or participate in general discussions about
FreeFem++ with the <a
href="https://www.ljll.math.upmc.fr/mailman/listinfo/freefempp">FreeFem++
mailing list</a>
   </li>
   
    <li><b>16/10/2008</b> Ateliers de Simualtion Num&eacute;rique, (Setif,Alg&eacute;rie)
 &nbsp;: <a
href="http://www.cmap.polytechnique.fr/spip.php?article239"> details</a>, par 
<a href="http://www.cmap.polytechnique.fr/spip.php?article105"> Olivier Pantz </a>
   </li>
   
    <li><b>14-15/09/2009</b></b> 
<font color=black>  The first tutorial and Workshop on FreeFem++  ,   held September 14th and 15th, 2009, in Paris at IHP,  amphi Hermite ,11 Rue Pierre et Marie Curie.</font>
 <A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2009"> All Presentation, examples, and data are here  </A>    </li>
   
   
    <li> <b>1-2/09/2010</b> 
<font >  
The second tutorial and Workshop on FreeFem++  , 
 held September 1st and 2nd, 2010, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</font>
<A HREF="http://www.freefem.org/ff2a3/ff++days-2010/"> All Presentation, examples, and data are here </A>
  </li>
    
    <li><b>5-7/12/2011</b><font color=000000> <bf> 
The THIRD tutorial and Workshop on FreeFem++  , 
 held december 5th,6th and 7th, 2010, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf> 
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2011/Schedule.htm">All Presentation, examples, and data are here  here  </A>
 </li>
    
      <li><b>6-7/12/2012</b><font color=000000> <bf>  <font color=black> 
The FOURTH  tutorial and Workshop on FreeFem++ , 
 held december 7th and 7th, 2012, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf> 
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2012/main.htm"> Main </A>, 
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2012/Schedule.html"> All Presentation, examples </A> and
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2012/.">  directory this all data  </A>.
 </font></li>
      <li><b>10-13/12/2013</b><font > <bf>  <font > 
 <A HREF="http://www.ljll.math.upmc.fr/FreeFem++"> 
The Fifth   tutorial and Workshop on FreeFem++ </A>, 
 held december 10th,11th and 12th, 2013, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf> 
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2013/main.htm"> Main </A>, 
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2013/Schedule.html"> All Presentation, examples </A> and
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2013/.">  directory this all data  </A>.
 </font></li>

       <li><b>27-28/05/2014</b><font > <bf>  <font > 
 <A HREF="http://www.tims.ntu.edu.tw/workshop/Default/index.php?WID=177"> 
CASTS-LJLL workshop </A>  on Applied Mathematics and Mathematical Sciences </bf>  A programming language for the FEM : FreeFem++ 

<A HREF="http://homepage.ntu.edu.tw/~twhsheu/twsiamff++/activities.html#activities"> Activity </A>, 
<A HREF="http://homepage.ntu.edu.tw/~twhsheu/twsiamff++/courses.html"> Courses </A>.
</font> </font></li>
   
     <li><font > <bf>  <font color=black> 
       The Sixth   tutorial and Workshop on FreeFem++ , 
 held december 9th,10th and 11th, 2014, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf>  
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2014/Schedule.html"> Schedule, All Presentation, examples </A> and
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2014/.">  directory this all data  </A>.
 </font></li> 
 
  <li> <font color=black>  <b>16-20/03/2015</b> <bf>  </font > 

<A HREF="http://www.maths.ox.ac.uk">  Mini Cours FreeFem++, Maths departement, Universty of  Oxford, England  <A/> 16-20 March . 2015   
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++/2015-oxford"> The directory with all data  </A> 
 </li>
 
          <li><font > <bf>  <font color=black> <font> 
       The 7th   tutorial and Workshop on FreeFem++ </font>
 held december 15th and 16th, 2015, in Paris at Universit&eacute Pierre
et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf>  
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2015/Schedule.html"> Schedule, All Presentation, examples </A> and
<A HREF="https://www.ljll.math.upmc.fr/hecht/ftp/ff++days/2015/.">  directory this all data  </A>.
 </font></li> 
 <li><font > <bf>  <font color=red > 
         The 8th   tutorial and Workshop on FreeFem++ 
   <A HREF="https://www.ljll.math.upmc.fr/freefem++/">  (inscription here)</A>, 
   held december 8th and 9th, 2016, in Paris at Universit&eacute Pierre
  et Marie Curie, Barre 16-15, 3ieme,  4 place Jussieu, Paris</bf>  
  <A HREF="https://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2016/Schedule.html"> Schedule, All Presentation, examples </A> and
  <A HREF="https://www.ljll.math.upmc.fr/~hecht/ftp/ff++days/2016/.">  directory this all data  </A>.
   </font></li> 

  </ul>
  
</div> 


<div class="thema"> HPC and FreeFem++  </div>
<ul>
<li> Solver a problem with  one  billion of unknows  in  2 minutes! The computation will done in 2 minutes on the  Curie Thin Node@CEA machine (6144 coeurs de 4Go de mémoire chacun),  Thank to P. Jolivet, and F. Nataf. </li>
<li>  In construction </li>


</ul>

 
<address></address>
<!-- hhmts start --> Last modified: 4 Nov 2015 <!-- hhmts end -->
</body> </html>
</body>
</html>
